@@ -1,6 +1,6 @@
 import pickle
 
-from docker_config import Configuration
+from docker_ascii_map.docker_config import Configuration
 
 
 def dump_configuration(config: Configuration) -> bytes:
